# coding: utf-8


class Config:

    """Конфигурация пакета m3-object-statuses."""

    #: Флаги, определяющие необходимость учета неудачных попыток смены статуса.
    #:
    #: Ключ ``None`` указывает на действие по умолчанию. Также ключами могут
    #: быть имена моделей в виде ``'app_label.ModelName'``, что будет
    #: указывать на то, что для конктерной модели и её потомков поведение будет
    #: отличаться от поведения по умолчанию.
    #:
    #: Значение ``False`` указывает на то, что неудачные попытки смены статуса
    #: объекта не будут сохраняться в истории смены статусов.
    #:
    #: Попытка смены статуса считается неудачной в том случае, если хотя бы
    #: один из обработчиков сигнала :obj:`~m3_object_statuses.signals.
    #: pre_status_change` вернет ``False``, либо в случае, если проверка
    #: (валидация) объекта, у которого меняется статус, завершилась с ошибкой
    #: :exc:`~django.core.exception.ValidationError`.
    ignore_unsuccessful_transitions = {
        None: True,
    }


#: Конфигурация пакета.
#:
#: При необходимости изменения настроек по умолчанию данный атрибут модуля
#: перезаписывается экземпляром другого класса конфигурации, либо значения
#: параметров изменяются прямо в данном объекте.
config = Config()
